@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2020 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2022 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -9,8 +9,7 @@
 
 
 
-fill <-
-fill1 <- fill2 <- fill3 <-
+fill1 <- fill2 <- fill3 <- fill4 <-
   function(x, values = 0, ncolx = ncol(x)) {
   x <- as.matrix(x)
   matrix(values, nrow = nrow(x), ncol = ncolx, byrow = TRUE)
